@@ -1,5 +1,5 @@
 package LWP::MemberMixin;
-$LWP::MemberMixin::VERSION = '6.22';
+$LWP::MemberMixin::VERSION = '6.23';
 sub _elem {
     my $self = shift;
     my $elem = shift;
@@ -21,8 +21,7 @@ LWP::MemberMixin - Member access mixin class
 =head1 SYNOPSIS
 
  package Foo;
- require LWP::MemberMixin;
- @ISA=qw(LWP::MemberMixin);
+ use base qw(LWP::MemberMixin);
 
 =head1 DESCRIPTION
 
@@ -30,11 +29,13 @@ A mixin class to get methods that provide easy access to member
 variables in the C<%$self>.
 Ideally there should be better Perl language support for this.
 
+=head1 METHODS
+
 There is only one method provided:
 
-=over 4
+=head2 _elem
 
-=item _elem($elem [, $val])
+    _elem($elem [, $val])
 
 Internal method to get/set the value of member variable
 C<$elem>. If C<$val> is present it is used as the new value
@@ -42,6 +43,4 @@ for the member variable.  If it is not present the current
 value is not touched. In both cases the previous value of
 the member variable is returned.
 
-=back
-
 =cut
